-- Copyright (C) 2010-2011 Papavasileiou Dimitris                             
--                                                                      
-- This program is free software: you can redistribute it and/or modify 
-- it under the terms of the GNU General Public License as published by 
-- the Free Software Foundation, either version 3 of the License, or    
-- (at your option) any later version.                                  
--                                                                      
-- This program is distributed in the hope that it will be useful,      
-- but WITHOUT ANY WARRANTY; without even the implied warranty of       
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        
-- GNU General Public License for more details.                         
--                                                                      
-- You should have received a copy of the GNU General Public License    
-- along with this program.  If not, see <http://www.gnu.org/licenses/>.

resources.dofile "slipstream/vehicles/motorcycle-largesports.lua"
resources.dofile "slipstream/engines/motorcycle-largesports.lua"
resources.dofile "slipstream/controls/motorcycle-largesports.lua"
resources.dofile "slipstream/tyres/motorcycle-120-70.lua"
resources.dofile "slipstream/tyres/motorcycle-180-55.lua"

blueprint.model = "motorcycle"
